from AccessControl import getSecurityManager
from AccessControl.User import UserFolder
from OFS.ObjectManager import ObjectManager
import Globals

class ZUserFolder(ObjectManager, UserFolder):
    """Similar to Standard UserFolder object (but better)

    A UserFolder holds User objects which contain information
    about users including name, password domain, and roles.
    UserFolders function chiefly to control access by authenticating
    users and binding them to a collection of roles.

    A ZUserFolder allows the contained User objects to be ZClasses.
    Now you can access methods and properties of the AUTHENTICATED_USER
    that you have defined in the ZClass.
    """

    meta_type='Z User Folder'
    title    ='Z User Folder'
    icon     ='p_/UserFolder'

    manage_options=(
        (
        {'label':'Contents', 'action':'manage_main',
#         'help':('OFSP','User-Folder_Contents.stx')
         },
        )
        )

    __ac_permissions__=(
        ('Manage users',
         ('manage_users','getUserNames', 'getUser', 'getUsers',
          'getUserById', 'user_names', 'setDomainAuthenticationMode',
          'manage_changeUser'
          )
         ),
        )

    def filtered_meta_types(self, user=None):
        # Return a list of the types for which the user has
        # adequate permission to add that type of object.
            
        meta_types = ObjectManager.filtered_meta_types(self, user)

        zclasses = {}
        zc = self.aq_acquire('_getProductRegistryData')('zclasses')
        for z in zc:
            zclasses[z['meta_type']] = z['meta_class']

        zuser_meta_types = []
        for meta_type in meta_types:
            zclass=zclasses.get(meta_type['name'], None)
            if zclass:
                if 'ZUser' in zclass.ZClassBaseClassNames():
                    zuser_meta_types.append(meta_type)        
        return zuser_meta_types    
    
    def _setObject(self,id,object,roles=None,user=None, set_owner=1):
        ObjectManager._setObject(self,id,object,roles=None,user=None, set_owner=1)
        self.data[id]=object
        
    def _delObject(self, id, dp=1):
        del self.data[id]
        ObjectManager._delObject(self, id, dp)
        
    def manage_changeUser(self,name,password,confirm,roles,domains):
        """Change a user"""
        error = None
        error = self._changeUser(name,password,confirm,roles,domains)
        if error:
            return error

Globals.default__class_init__(ZUserFolder)

def manage_addZUserFolder(self,dtself=None,REQUEST=None,**ignored):
    """ """
    f=ZUserFolder()
    self=self.this()
    try:    self._setObject('acl_users', f)
    except: return MessageDialog(
                   title  ='Item Exists',
                   message='This object already contains a User Folder',
                   action ='%s/manage_main' % REQUEST['URL1'])
    self.__allow_groups__=f
    if REQUEST is not None:
        REQUEST['RESPONSE'].redirect(self.absolute_url()+'/manage_main')